@@ -2,10 +2,12 @@ r""" **Layer** implements useful PyTorch layers that can be easily incorporated
 
 It contains:
     - SE (Squeeze-Excitation) for Convnets,
+    - DenseBlock (implemented in DenseNet) for Convnets,
     - FlipConv2d (Special Conv2d layer that's almost invariant to image flipping) for Convnets,
     - MultiHeadAttention implemented in the transformers paper (Attention is all you need).
     - MultiHeadAttentionV2 is a modified version.
 """
 from .FlipConv2d import FlipConv2d
 from .SE import SE
-from .MultiHeadAttention import MultiHeadAttention, MultiHeadAttentionV2
\ No newline at end of file
+from .MultiHeadAttention import MultiHeadAttention, MultiHeadAttentionV2
+from .DenseBlock import DenseBlock
\ No newline at end of file
